This package contains some basic functions to create time/frequency peakmaps and run the frequency-Hough Transform on them. Users are highly encouraged to go through the [tutorial](https://colab.research.google.com/drive/1Ym90BZyehZbj7cfUZU82jGcJ2J1iBdcU#scrollTo=mYJ6RwMZxxmK) available on [my website](https://andrew-l-miller.github.io/post/tutorial/).

These codes rely on [PyFstat](https://github.com/PyFstat/PyFstat), [LAL](https://doi.org/10.7935/GT1W-FZ16), and codes therein and are conceputally based on the [frequency-Hough transform](https://doi.org/10.1103/PhysRevD.90.042002) and codes in the [Snag toolbox](https://www.mathworks.com/matlabcentral/fileexchange/9703-snag).

The package [pyhough](https://pypi.org/project/pyhough/) is installable in the following way:

```
pip install pyhough

```
Please contact me if you have any questions!
